@@ -3,6 +3,11 @@ from datetime import datetime
 from typing import Any
 
 
+def postgres_date(date_str: str) -> datetime:
+    """Parse a postgres compatible date string into datetime object"""
+    return datetime.strptime(date_str, "%Y-%m-%dT%H:%M:%S+00:00")
+
+
 def datetime_parser(dct: dict[str, Any]) -> dict[str, Any]:
     """
     Used as object hook in json loads method to parse postgres dates strings
